@@ -29,8 +29,6 @@
  * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
- *
- * $Id: verbs.c 9722 2006-10-04 23:57:10Z roland $
  */
 
 #if HAVE_CONFIG_H
@@ -123,13 +121,24 @@ static struct ibv_mr *__mthca_reg_mr(struct ibv_pd *pd, void *addr,
 {
 	struct ibv_mr *mr;
 	struct ibv_reg_mr cmd;
+	int ret;
 
 	mr = malloc(sizeof *mr);
 	if (!mr)
 		return NULL;
 
-	if (ibv_cmd_reg_mr(pd, addr, length, hca_va,
-			   access, mr, &cmd, sizeof cmd)) {
+#ifdef IBV_CMD_REG_MR_HAS_RESP_PARAMS
+	{
+		struct ibv_reg_mr_resp resp;
+
+		ret = ibv_cmd_reg_mr(pd, addr, length, hca_va, access, mr,
+				     &cmd, sizeof cmd, &resp, sizeof resp);
+	}
+#else
+	ret = ibv_cmd_reg_mr(pd, addr, length, hca_va, access, mr,
+			     &cmd, sizeof cmd);
+#endif
+	if (ret) {
 		free(mr);
 		return NULL;
 	}
@@ -540,7 +549,7 @@ struct ibv_qp *mthca_create_qp(struct ibv_pd *pd, struct ibv_qp_init_attr *attr)
 	} else {
 		cmd.sq_db_page  = cmd.rq_db_page  =
 		cmd.sq_db_index = cmd.rq_db_index = 0;
-	}		
+	}
 
 	ret = ibv_cmd_create_qp(pd, &qp->ibv_qp, attr, &cmd.ibv_cmd, sizeof cmd,
 				&resp, sizeof resp);
